@@ -1,4 +1,4 @@
-use anyhow::Result;
+use anyhow::{anyhow, Context, Result};
 use clap::Command;
 use std::{borrow::Cow, env};
 use url::Url;
@@ -10,7 +10,7 @@ use himalaya::{
     printer::StdoutPrinter,
     tpl,
 };
-use himalaya_lib::{
+use pimalaya_email::{
     BackendBuilder, BackendConfig, ImapBackend, SenderBuilder, DEFAULT_INBOX_FOLDER,
 };
 
@@ -77,8 +77,7 @@ fn main() -> Result<()> {
         _ => (),
     }
 
-    // checks completion command before configs
-    // https://github.com/soywod/himalaya/issues/115
+    // also checks man command before configs
     match man::args::matches(&m)? {
         Some(man::args::Cmd::GenerateAll(dir)) => {
             return man::handlers::generate(dir, create_app());
@@ -123,11 +122,7 @@ fn main() -> Result<()> {
         Some(account::args::Cmd::List(max_width)) => {
             return account::handlers::list(max_width, &account_config, &config, &mut printer);
         }
-        Some(account::args::Cmd::Sync(dry_run)) => {
-            let folder = match folder {
-                Some(folder) => Some(account_config.folder_alias(folder)?),
-                None => None,
-            };
+        Some(account::args::Cmd::Sync(folders_strategy, dry_run)) => {
             let backend = BackendBuilder::new()
                 .sessions_pool_size(8)
                 .disable_cache(true)
@@ -136,7 +131,7 @@ fn main() -> Result<()> {
                 &account_config,
                 &mut printer,
                 backend.as_ref(),
-                &folder,
+                folders_strategy,
                 dry_run,
             )?;
             backend.close()?;
@@ -147,24 +142,44 @@ fn main() -> Result<()> {
 
     // checks folder commands
     match folder::args::matches(&m)? {
-        Some(folder::args::Cmd::Expunge) => {
-            let folder = account_config.folder_alias(folder.unwrap_or(DEFAULT_INBOX_FOLDER))?;
+        Some(folder::args::Cmd::Create) => {
+            let folder = folder
+                .ok_or_else(|| anyhow!("the folder argument is missing"))
+                .context("cannot create folder")?;
+            let folder = account_config.folder_alias(folder)?;
             let mut backend = BackendBuilder::new()
                 .disable_cache(disable_cache)
                 .build(&account_config, &backend_config)?;
-            return folder::handlers::expunge(&folder, &mut printer, backend.as_mut());
+            return folder::handlers::create(&mut printer, backend.as_mut(), &folder);
         }
         Some(folder::args::Cmd::List(max_width)) => {
             let mut backend = BackendBuilder::new()
                 .disable_cache(disable_cache)
                 .build(&account_config, &backend_config)?;
             return folder::handlers::list(
-                max_width,
                 &account_config,
                 &mut printer,
                 backend.as_mut(),
+                max_width,
             );
         }
+        Some(folder::args::Cmd::Expunge) => {
+            let folder = account_config.folder_alias(folder.unwrap_or(DEFAULT_INBOX_FOLDER))?;
+            let mut backend = BackendBuilder::new()
+                .disable_cache(disable_cache)
+                .build(&account_config, &backend_config)?;
+            return folder::handlers::expunge(&mut printer, backend.as_mut(), &folder);
+        }
+        Some(folder::args::Cmd::Delete) => {
+            let folder = folder
+                .ok_or_else(|| anyhow!("the folder argument is missing"))
+                .context("cannot delete folder")?;
+            let folder = account_config.folder_alias(folder)?;
+            let mut backend = BackendBuilder::new()
+                .disable_cache(disable_cache)
+                .build(&account_config, &backend_config)?;
+            return folder::handlers::delete(&mut printer, backend.as_mut(), &folder);
+        }
         _ => (),
     }
 
